@@ -119,8 +119,26 @@ class AccountTestCase(ModoTestCase):
         account = User.objects.get(username=values["username"])
         self.assertEqual(account.language, "fr")
 
-    def test_forward_updated_on_edit(self):
+    def test_create_account_with_existing_alias(self):
+        alias = models.Alias.objects.get(address="alias@test.com")
+        alias.set_recipients(["user@external.com"])
+        values = {
+            "email": "tester@test.com",
+            "username": "tester@test.com",
+            "role": "SimpleUsers",
+            "random_password": "on",
+            "quota_act": True,
+            "is_active": True,
+            "stepid": "step2",
+            "aliases": "alias@test.com",
+        }
+        self.ajax_post(reverse("admin:account_add"), values)
+        self.assertTrue(alias.aliasrecipient_set.count() == 2)
+
+    def test_aliases_update_on_disable(self):
+        """Check if aliases are updated when account is disabled."""
         account = User.objects.get(username="user@test.com")
+        internal = models.Alias.objects.get(address=account.email, internal=True)
         forward = models.Alias.objects.create(address=account.email, internal=False)
         values = {
             "username": "user@test.com",
@@ -133,12 +151,16 @@ class AccountTestCase(ModoTestCase):
         self.ajax_post(
             reverse("admin:account_change", args=[account.id]), values
         )
+        internal.refresh_from_db()
+        self.assertFalse(internal.enabled)
         forward.refresh_from_db()
         self.assertFalse(forward.enabled)
         values["is_active"] = True
         self.ajax_post(
             reverse("admin:account_change", args=[account.id]), values
         )
+        internal.refresh_from_db()
+        self.assertTrue(internal.enabled)
         forward.refresh_from_db()
         self.assertTrue(forward.enabled)
 
