@@ -150,6 +150,10 @@ class User(AbstractUser):
         """Return detail url for this user."""
         return reverse("admin:account_detail", args=[self.pk])
 
+    @property
+    def type(self):
+        return "account"
+
     @property
     def tags(self):
         return [{"name": "account", "label": _("account"), "type": "idt"},
@@ -361,13 +365,8 @@ class User(AbstractUser):
         signals.account_imported.send(
             sender=self.__class__, user=user, account=self, row=row[7:])
 
-    def to_csv(self, csvwriter):
-        """Export this account.
-
-        The CSV format is used to export.
-
-        :param csvwriter: csv object
-        """
+    def to_csv_row(self):
+        """Return row that can be included in a CSV file."""
         row = [
             "account",
             smart_text(self.username),
@@ -382,7 +381,16 @@ class User(AbstractUser):
             sender=self.__class__, user=self)
         for result in results:
             row += result[1]
-        csvwriter.writerow(row)
+        return row
+
+    def to_csv(self, csvwriter):
+        """Export this account.
+
+        The CSV format is used to export.
+
+        :param csvwriter: csv object
+        """
+        csvwriter.writerow(self.to_csv_row())
 
 
 reversion.register(User)
